@@ -1,11 +1,9 @@
-# !/usr/bin/env python
 """
 Define the unit tests for the :mod:`colour.models.rgb.rgb_colourspace` module.
 """
 
 import re
 import textwrap
-import unittest
 from itertools import product
 
 import numpy as np
@@ -44,13 +42,13 @@ __all__ = [
 ]
 
 
-class TestRGB_Colourspace(unittest.TestCase):
+class TestRGB_Colourspace:
     """
     Define :class:`colour.colour.models.RGB_Colourspace` class unit
     tests methods.
     """
 
-    def setUp(self):
+    def setup_method(self):
         """Initialise the common tests attributes."""
 
         p = np.array([0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700])
@@ -85,7 +83,7 @@ class TestRGB_Colourspace(unittest.TestCase):
         )
 
         for attribute in required_attributes:
-            self.assertIn(attribute, dir(RGB_Colourspace))
+            assert attribute in dir(RGB_Colourspace)
 
     def test_required_methods(self):
         """Test the presence of required methods."""
@@ -100,7 +98,7 @@ class TestRGB_Colourspace(unittest.TestCase):
         )
 
         for method in required_methods:
-            self.assertIn(method, dir(RGB_Colourspace))
+            assert method in dir(RGB_Colourspace)
 
     def test__str__(self):
         """
@@ -108,8 +106,7 @@ class TestRGB_Colourspace(unittest.TestCase):
         method.
         """
 
-        self.assertEqual(
-            re.sub(" at 0x\\w+>", "", str(self._colourspace)),
+        assert re.sub(" at 0x\\w+>", "", str(self._colourspace)) == (
             textwrap.dedent(
                 """
     RGB Colourspace
@@ -137,7 +134,7 @@ class TestRGB_Colourspace(unittest.TestCase):
     Use Derived NPM    : False
     Use Derived NPM -1 : False
                 """
-            ).strip(),
+            ).strip()
         )
 
     def test__repr__(self):
@@ -146,8 +143,7 @@ class TestRGB_Colourspace(unittest.TestCase):
 __repr__` method.
         """
 
-        self.assertEqual(
-            re.sub(" at 0x\\w+>", "", repr(self._colourspace)),
+        assert re.sub(" at 0x\\w+>", "", repr(self._colourspace)) == (
             textwrap.dedent(
                 """
         RGB_Colourspace('RGB Colourspace',
@@ -167,7 +163,7 @@ __repr__` method.
                         False,
                         False)
                 """
-            ).strip(),
+            ).strip()
         )
 
     def test_use_derived_transformation_matrices(self):
@@ -243,7 +239,7 @@ chromatically_adapt` method.
             colourspace.whitepoint, whitepoint_t, atol=TOLERANCE_ABSOLUTE_TESTS
         )
 
-        self.assertEqual(colourspace.whitepoint_name, "D50")
+        assert colourspace.whitepoint_name == "D50"
 
         np.testing.assert_allclose(
             colourspace.primaries,
@@ -258,18 +254,14 @@ chromatically_adapt` method.
 
         np.testing.assert_allclose(
             colourspace.matrix_RGB_to_XYZ,
-            normalised_primary_matrix(
-                colourspace.primaries, colourspace.whitepoint
-            ),
+            normalised_primary_matrix(colourspace.primaries, colourspace.whitepoint),
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
         np.testing.assert_allclose(
             colourspace.matrix_XYZ_to_RGB,
             np.linalg.inv(
-                normalised_primary_matrix(
-                    colourspace.primaries, colourspace.whitepoint
-                )
+                normalised_primary_matrix(colourspace.primaries, colourspace.whitepoint)
             ),
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
@@ -280,10 +272,10 @@ chromatically_adapt` method.
         method.
         """
 
-        self.assertIsNot(self._colourspace.copy(), self)
+        assert self._colourspace.copy() is not self
 
 
-class TestXYZ_to_RGB(unittest.TestCase):
+class TestXYZ_to_RGB:
     """
     Define :func:`colour.models.rgb.rgb_colourspace.XYZ_to_RGB` definition
     unit tests methods.
@@ -480,13 +472,11 @@ class TestXYZ_to_RGB(unittest.TestCase):
 
         cases = [-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]
         cases = np.array(list(set(product(cases, repeat=3))))
-        M = np.vstack([cases[0, ...], cases[0, ...], cases[0, ...]]).reshape(
-            [3, 3]
-        )
+        M = np.reshape(np.vstack([cases[0, ...], cases[0, ...], cases[0, ...]]), (3, 3))
         XYZ_to_RGB(cases, cases[..., 0:2], cases[..., 0:2], M)
 
 
-class TestRGB_to_XYZ(unittest.TestCase):
+class TestRGB_to_XYZ:
     """
     Define :func:`colour.models.rgb.rgb_colourspace.RGB_to_XYZ` definition
     unit tests methods.
@@ -683,13 +673,11 @@ class TestRGB_to_XYZ(unittest.TestCase):
 
         cases = [-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]
         cases = np.array(list(set(product(cases, repeat=3))))
-        M = np.vstack([cases[0, ...], cases[0, ...], cases[0, ...]]).reshape(
-            [3, 3]
-        )
+        M = np.reshape(np.vstack([cases[0, ...], cases[0, ...], cases[0, ...]]), (3, 3))
         RGB_to_XYZ(cases, cases[..., 0:2], cases[..., 0:2], M)
 
 
-class TestMatrix_RGB_to_RGB(unittest.TestCase):
+class TestMatrix_RGB_to_RGB:
     """
     Define :func:`colour.models.rgb.rgb_colourspace.matrix_RGB_to_RGB`
     definition unit tests methods.
@@ -730,9 +718,7 @@ class TestMatrix_RGB_to_RGB(unittest.TestCase):
         )
 
         np.testing.assert_allclose(
-            matrix_RGB_to_RGB(
-                aces_2065_1_colourspace, aces_cg_colourspace, "Bradford"
-            ),
+            matrix_RGB_to_RGB(aces_2065_1_colourspace, aces_cg_colourspace, "Bradford"),
             np.array(
                 [
                     [1.45143932, -0.23651075, -0.21492857],
@@ -744,9 +730,7 @@ class TestMatrix_RGB_to_RGB(unittest.TestCase):
         )
 
         np.testing.assert_allclose(
-            matrix_RGB_to_RGB(
-                aces_2065_1_colourspace, sRGB_colourspace, "Bradford"
-            ),
+            matrix_RGB_to_RGB(aces_2065_1_colourspace, sRGB_colourspace, "Bradford"),
             np.array(
                 [
                     [2.52140089, -1.13399575, -0.38756186],
@@ -776,7 +760,7 @@ class TestMatrix_RGB_to_RGB(unittest.TestCase):
         )
 
 
-class TestRGB_to_RGB(unittest.TestCase):
+class TestRGB_to_RGB:
     """
     Define :func:`colour.models.rgb.rgb_colourspace.RGB_to_RGB` definition
     unit tests methods.
@@ -946,7 +930,3 @@ class TestRGB_to_RGB(unittest.TestCase):
         cases = [-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]
         cases = np.array(list(set(product(cases, repeat=3))))
         RGB_to_RGB(cases, aces_2065_1_colourspace, sRGB_colourspace)
-
-
-if __name__ == "__main__":
-    unittest.main()
